==> kubernetes-model-policy-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodDisruptionBudgetFluentImpl<A extends PodDisruptionBudgetFluent<A>> extends BaseFluent<A> implements PodDisruptionBudgetFluent<A>{
  public PodDisruptionBudgetFluentImpl() {
  }
  public PodDisruptionBudgetFluentImpl(PodDisruptionBudget instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodDisruptionBudgetSpecBuilder spec;
  private PodDisruptionBudgetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodDisruptionBudgetFluent.MetadataNested<A> withNewMetadata() {
    return new PodDisruptionBudgetFluentImpl.MetadataNestedImpl();
  }
  public PodDisruptionBudgetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodDisruptionBudgetFluentImpl.MetadataNestedImpl(item);
  }
  public PodDisruptionBudgetFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodDisruptionBudgetFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodDisruptionBudgetFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodDisruptionBudgetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodDisruptionBudgetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodDisruptionBudgetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodDisruptionBudgetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodDisruptionBudgetFluent.SpecNested<A> withNewSpec() {
    return new PodDisruptionBudgetFluentImpl.SpecNestedImpl();
  }
  public PodDisruptionBudgetFluent.SpecNested<A> withNewSpecLike(PodDisruptionBudgetSpec item) {
    return new PodDisruptionBudgetFluentImpl.SpecNestedImpl(item);
  }
  public PodDisruptionBudgetFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodDisruptionBudgetFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodDisruptionBudgetSpecBuilder().build());
  }
  public PodDisruptionBudgetFluent.SpecNested<A> editOrNewSpecLike(PodDisruptionBudgetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodDisruptionBudgetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodDisruptionBudgetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodDisruptionBudgetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodDisruptionBudgetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodDisruptionBudgetFluent.StatusNested<A> withNewStatus() {
    return new PodDisruptionBudgetFluentImpl.StatusNestedImpl();
  }
  public PodDisruptionBudgetFluent.StatusNested<A> withNewStatusLike(PodDisruptionBudgetStatus item) {
    return new PodDisruptionBudgetFluentImpl.StatusNestedImpl(item);
  }
  public PodDisruptionBudgetFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodDisruptionBudgetFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodDisruptionBudgetStatusBuilder().build());
  }
  public PodDisruptionBudgetFluent.StatusNested<A> editOrNewStatusLike(PodDisruptionBudgetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodDisruptionBudgetFluentImpl that = (PodDisruptionBudgetFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodDisruptionBudgetFluent.MetadataNested<N>> implements PodDisruptionBudgetFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodDisruptionBudgetSpecFluentImpl<PodDisruptionBudgetFluent.SpecNested<N>> implements PodDisruptionBudgetFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodDisruptionBudgetSpec item) {
      this.builder = new PodDisruptionBudgetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodDisruptionBudgetSpecBuilder(this);
    }
    PodDisruptionBudgetSpecBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodDisruptionBudgetStatusFluentImpl<PodDisruptionBudgetFluent.StatusNested<N>> implements PodDisruptionBudgetFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodDisruptionBudgetStatus item) {
      this.builder = new PodDisruptionBudgetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodDisruptionBudgetStatusBuilder(this);
    }
    PodDisruptionBudgetStatusBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-policy-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodDisruptionBudgetFluentImpl<A extends PodDisruptionBudgetFluent<A>> extends BaseFluent<A> implements PodDisruptionBudgetFluent<A>{
  public PodDisruptionBudgetFluentImpl() {
  }
  public PodDisruptionBudgetFluentImpl(PodDisruptionBudget instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodDisruptionBudgetSpecBuilder spec;
  private PodDisruptionBudgetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodDisruptionBudgetFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PodDisruptionBudgetFluentImpl.MetadataNestedImpl();
  }
  public PodDisruptionBudgetFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodDisruptionBudgetFluentImpl.MetadataNestedImpl(item);
  }
  public PodDisruptionBudgetFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodDisruptionBudgetFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodDisruptionBudgetFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodDisruptionBudgetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodDisruptionBudgetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodDisruptionBudgetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodDisruptionBudgetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodDisruptionBudgetFluentImpl.SpecNested<A> withNewSpec() {
    return new PodDisruptionBudgetFluentImpl.SpecNestedImpl();
  }
  public PodDisruptionBudgetFluentImpl.SpecNested<A> withNewSpecLike(PodDisruptionBudgetSpec item) {
    return new PodDisruptionBudgetFluentImpl.SpecNestedImpl(item);
  }
  public PodDisruptionBudgetFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodDisruptionBudgetFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodDisruptionBudgetSpecBuilder().build());
  }
  public PodDisruptionBudgetFluentImpl.SpecNested<A> editOrNewSpecLike(PodDisruptionBudgetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodDisruptionBudgetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodDisruptionBudgetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodDisruptionBudgetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodDisruptionBudgetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodDisruptionBudgetFluentImpl.StatusNested<A> withNewStatus() {
    return new PodDisruptionBudgetFluentImpl.StatusNestedImpl();
  }
  public PodDisruptionBudgetFluentImpl.StatusNested<A> withNewStatusLike(PodDisruptionBudgetStatus item) {
    return new PodDisruptionBudgetFluentImpl.StatusNestedImpl(item);
  }
  public PodDisruptionBudgetFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodDisruptionBudgetFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodDisruptionBudgetStatusBuilder().build());
  }
  public PodDisruptionBudgetFluentImpl.StatusNested<A> editOrNewStatusLike(PodDisruptionBudgetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodDisruptionBudgetFluentImpl that = (PodDisruptionBudgetFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodDisruptionBudgetFluentImpl.MetadataNested<N>> implements PodDisruptionBudgetFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodDisruptionBudgetSpecFluentImpl<PodDisruptionBudgetFluentImpl.SpecNested<N>> implements PodDisruptionBudgetFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodDisruptionBudgetSpec item) {
      this.builder = new PodDisruptionBudgetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodDisruptionBudgetSpecBuilder(this);
    }
    PodDisruptionBudgetSpecBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodDisruptionBudgetStatusFluentImpl<PodDisruptionBudgetFluentImpl.StatusNested<N>> implements PodDisruptionBudgetFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodDisruptionBudgetStatus item) {
      this.builder = new PodDisruptionBudgetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodDisruptionBudgetStatusBuilder(this);
    }
    PodDisruptionBudgetStatusBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
